==> geant4.9.6.p02.tar.gz: geant4.9.6.p02/examples/.doxygen/Doxymodules_runAndEvent.h <==
// $Id: Doxymodules_runAndEvent.h 60059 2012-06-27 13:00:49Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_runAndEvent.h
/// \brief The page that defines the extended/runAndEvent examples modules 


/** @defgroup extended_runAndEvent runAndEvent
 *  Extended runAndEvent examples classes
 *  @{
 */

/** @defgroup extended_runAndEvent_RE01 RE01
 *  RunAndEvent example RE01
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE01BosonPhysics {};
  class RE01CalorimeterHit {};
  class RE01CalorimeterParametrisation {};
  class RE01CalorimeterROGeometry {};
  class RE01CalorimeterSD {};
  class RE01DecayPhysics {};
  class RE01DetectorConstruction {};
  class RE01DetectorParameterDef {};
  class RE01DummySD {};
  class RE01EventAction {};
  class RE01Field {};
  class RE01HadronPhysics {};
  class RE01IonPhysics {};
  class RE01LeptonPhysics {};
  class RE01PhysicsList {};
  class RE01PrimaryGeneratorAction {};
  class RE01PrimaryGeneratorMessenger {};
  class RE01RegionInformation {};
  class RE01RunAction {};
  class RE01StackingAction {};
  class RE01SteppingAction {};
  class RE01TrackerHit {};
  class RE01TrackerParametrisation {};
  class RE01TrackerSD {};
  class RE01TrackInformation {};
  class RE01TrackingAction {};
  class RE01Trajectory {};

/** @} */

/** @defgroup extended_runAndEvent_RE02 RE02
 *  RunAndEvent example RE02
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE02DetectorConstruction {};
  class RE02EMPhysics {};
  class RE02EventAction {};
  class RE02GeneralPhysics {};
  class RE02HadronPhysics {};
  class RE02IonPhysics {};
  class RE02MuonPhysics {};
  class RE02NestedPhantomParameterisation {};
  class RE02PhysicsList {};
  class RE02PrimaryGeneratorAction {};
  class RE02PSCellFlux {};
  class RE02PSEnergyDeposit {};
  class RE02PSFlatSurfaceCurrent {};
  class RE02PSFlatSurfaceFlux {};
  class RE02PSNofStep {};
  class RE02PSPassageCellFlux {};
  class RE02RunAction {};
  class RE02Run {};

/** @} */

/** @defgroup extended_runAndEvent_RE03 RE03
 *  RunAndEvent example RE03
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE03DetectorConstruction {};
  class RE03PhysicsList {};
  class RE03PrimaryGeneratorAction {};
  class RE03UserScoreWriter {};

/** @} */

/** @defgroup extended_runAndEvent_RE04 RE04
 *  RunAndEvent example RE04
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE04DetectorConstruction {};
  class RE04EventAction {};
  class RE04ParallelWorldConstruction {};
  class RE04ParallelWorldParam {};
  class RE04PhysicsList {};
  class RE04PrimaryGeneratorAction {};
  class RE04SteppingAction {};
  class RE04TrackingAction {};
  class RE04Trajectory {};
  class RE04TrajectoryPoint {};

/** @} */


/** @} */

==> geant4.10.01.p02.tar.gz: geant4.10.01.p02/examples/.doxygen/Doxymodules_runAndEvent.h <==
// $Id: Doxymodules_runAndEvent.h 76473 2013-11-11 10:35:14Z gcosmo $
// The example class categories definitions for Doxygen

/// \file Doxymodules_runAndEvent.h
/// \brief The page that defines the extended/runAndEvent examples modules 


/** @defgroup extended_runAndEvent runAndEvent
 *  Extended runAndEvent examples classes
 *  @{
 */

/** @defgroup extended_runAndEvent_RE01 RE01
 *  RunAndEvent example RE01
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE01ActionInitialization {};
  class RE01CalorimeterHit {};
  class RE01CalorimeterParametrisation {};
  class RE01CalorimeterROGeometry {};
  class RE01CalorimeterSD {};
  class RE01DetectorConstruction {};
  class RE01DetectorParameterDef {};
  class RE01EventAction {};
  class RE01Field {};
  class RE01PhysicsList {};
  class RE01PrimaryGeneratorAction {};
  class RE01PrimaryGeneratorMessenger {};
  class RE01RegionInformation {};
  class RE01RunAction {};
  class RE01StackingAction {};
  class RE01SteppingAction {};
  class RE01TrackerHit {};
  class RE01TrackerParametrisation {};
  class RE01TrackerSD {};
  class RE01TrackInformation {};
  class RE01TrackingAction {};
  class RE01Trajectory {};
  class RE01UnknownDecayPhysics {};

/** @} */

/** @defgroup extended_runAndEvent_RE02 RE02
 *  RunAndEvent example RE02
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE02ActionInitialization {};
  class RE02DetectorConstruction {};
  class RE02EventAction {};
  class RE02NestedPhantomParameterisation {};
  class RE02PrimaryGeneratorAction {};
  class RE02PSCellFlux {};
  class RE02PSEnergyDeposit {};
  class RE02PSFlatSurfaceCurrent {};
  class RE02PSFlatSurfaceFlux {};
  class RE02PSNofStep {};
  class RE02PSPassageCellFlux {};
  class RE02RunAction {};
  class RE02Run {};

/** @} */

/** @defgroup extended_runAndEvent_RE03 RE03
 *  RunAndEvent example RE03
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE03ActionInitialization {};
  class RE03DetectorConstruction {};
  class RE03PrimaryGeneratorAction {};
  class RE03UserScoreWriter {};

/** @} */

/** @defgroup extended_runAndEvent_RE04 RE04
 *  RunAndEvent example RE04
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE04ActionInitialization {};
  class RE04DetectorConstruction {};
  class RE04EventAction {};
  class RE04ParallelWorldConstruction {};
  class RE04ParallelWorldParam {};
  class RE04PhysicsList {};
  class RE04PrimaryGeneratorAction {};
  class RE04SteppingAction {};
  class RE04TrackingAction {};
  class RE04Trajectory {};
  class RE04TrajectoryPoint {};

/** @} */

/** @defgroup extended_runAndEvent_RE05 RE05
 *  RunAndEvent example RE05
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE05ActionInitialization {};
  class RE05CalorimeterHit {};
  class RE05CalorimeterParametrisation {};
  class RE05CalorimeterROGeometry {};
  class RE05CalorimeterSD {};
  class RE05DetectorConstruction {};
  class RE05DetectorParameterDef {};
  class RE05DummySD {};
  class RE05EventAction {};
  class RE05Field {};
  class RE05MuonHit {};
  class RE05MuonSD {};
  class RE05PrimaryGeneratorAction {};
  class RE05PrimaryGeneratorMessenger {};
  class RE05RunAction {};
  class RE05StackingAction {};
  class RE05StackingActionMessenger {};
  class RE05SteppingAction {};
  class RE05SteppingVerbose {};
  class RE05TrackerHit {};
  class RE05TrackerParametrisation {};
  class RE05TrackerSD {};
  class RE05TrackingAction {};
  class RE05WorkerInitialization {};

/** @} */

/** @defgroup extended_runAndEvent_RE06 RE06
 *  RunAndEvent example RE06
 *  @ingroup extended_runAndEvent
 *  @{
 */

  class RE06ActionInitialization {};
  class RE06DetectorConstruction {};
  class RE06DetectorMessenger {};
  class RE06ParallelWorld {};
  class RE06PhysicsList {};
  class RE06PrimaryGeneratorAction {};
  class RE06RunAction {};
  class RE06Run {};
  class RE06SteppingVerbose {};
  class RE06WorkerInitialization {};

/** @} */

/** @} */
